import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Follows the real mouses location and states if it's
 * near the border of the screen or not. When it is it
 * is considered to be offscreen.
 * 
 * @author Joseph Lenton
 */
public class Mouse extends Actor
{
    // these are used for collision detection distances
    public static final int WIDTH = 120;
    public static final int HEIGHT = WIDTH;
    
    // width from edge for this to turn off
    private static final int BORDER = 15;
    
    public Mouse()
    {
        // inivisible image
        setImage( new GreenfootImage(1, 1) );
    }
    
    /**
     * Updates the mouses location.
     */
    public void act()
    {
        final MouseInfo mouse = Greenfoot.getMouseInfo();
        
        if ( mouse != null ) {
            setLocation( mouse.getX(), mouse.getY() );
        }
    }
    
    /**
     * This is considered to be 'off screen' if it is near
     * the border, where the mouse has probably gone off-screen.
     * @return False if this should not be followed, true if it should.
     */
    public boolean isOnScreen()
    {
        final int x = getX();
        final int y = getY();
        final World world = getWorld();
        
        return x > BORDER && y > BORDER && x < world.getWidth()-BORDER && y < world.getHeight()-BORDER;
    }
}
