import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;

/**
 * Adds all letters and gives them their starting birghtness angle
 * and color.
 * 
 * @author Joseph Lenton
 */
public class Scenario  extends World
{
    public static final Color BACKGROUND_COLOR = Color.BLACK;
    private static final double X_ANGLE_MULT = 1.0;
    private static final double Y_ANGLE_MULT = 0.3;
    
    private Mouse mouse;
    
    /**
     * Constructor for objects of class Scenario.
     */
    public Scenario()
    {
        super(800, 480, 1);
        
        for ( int x = Letter.WIDTH/2; x < getWidth(); x += Letter.WIDTH ) {
            for ( int y = Letter.HEIGHT/2; y < getHeight(); y += Letter.HEIGHT ) {
                final double angle = Math.toRadians( x*X_ANGLE_MULT + y*Y_ANGLE_MULT );
                final Letter letter = new Letter(
                        angle,
                        Greenfoot.getRandomNumber(255),
                        Greenfoot.getRandomNumber(255),
                        Greenfoot.getRandomNumber(255)
                );
                
                addObject( letter, x, y );
            }
        }
        
        final GreenfootImage background = new GreenfootImage( getWidth(), getHeight() );
        background.setColor( BACKGROUND_COLOR );
        background.fill();
        setBackground( background );
        
        this.mouse = new Mouse();
        addObject( mouse, 0, 0 );
        
        setActOrder(
                Mouse.class,
                Letter.class
        );
    }
    
    /**
     * @return The Mouse object within the scenario, if there is one.
     */
    public Mouse getMouse()
    {
        return mouse;
    }
}
